==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectInstanceparameter.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectinstanceparameter_h
#define objectinstanceparameter_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_instanceparameter {
  t_math _math;
  p_variable _parameter;
  int _parameter_isdefault : 1;
  p_expression _value;
  int _value_isdefault : 1;
};
#include <admsObject/objectVariable.h>
#include <admsObject/objectExpression.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_instanceparameter_getuid (p_instanceparameter myinstanceparameter);
win32_interface gboolean adms_instanceparameter_cmp (p_instanceparameter myinstanceparameter,p_instanceparameter refinstanceparameter);
win32_interface p_instanceparameter adms_instanceparameter_new_1 (p_variable myparameter);
#define adms_instanceparameter_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_instanceparameter_free(item)\
{\
  free(item);\
}
win32_interface p_adms adms_instanceparameter_new_impl (p_adms arguments[]);
win32_interface p_instanceparameter adms_instanceparameter_impl (void* member);
#define adms_instanceparameter(member) ((p_instanceparameter) (member))
#define adms_instanceparameter_new adms_instanceparameter_new_1
#define adms_instanceparameter_isdefault_parameter(instanceparameter) (adms_instanceparameter(instanceparameter)->_parameter_isdefault)
#define adms_instanceparameter_valueof_parameter(instanceparameter) (adms_instanceparameter(instanceparameter)->_parameter)
#define adms_instanceparameter_isdefault_value(instanceparameter) (adms_instanceparameter(instanceparameter)->_value_isdefault)
#define adms_instanceparameter_valueof_value(instanceparameter) (adms_instanceparameter(instanceparameter)->_value)
#define adms_instanceparameter_valueof_math(instanceparameter) ((p_math)instanceparameter)
#define adms_instanceparameter_valueof_adms(instanceparameter) ((p_adms)instanceparameter)
#define adms_instanceparameter_valueto_parameter(a,b) ((p_instanceparameter)a)->_parameter=(b)
win32_interface void adms_instanceparameter_valueto_parameter_impl (p_instanceparameter myinstanceparameter,p_variable _parameter);
#define adms_instanceparameter_valueto_value(a,b) ((p_instanceparameter)a)->_value=(b)
win32_interface void adms_instanceparameter_valueto_value_impl (p_instanceparameter myinstanceparameter,p_expression _value);
#endif /* objectinstanceparameter_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectInstanceparameter.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectinstanceparameter_h
#define objectinstanceparameter_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_instanceparameter {
  t_math _math;
  p_variable _parameter;
  int _parameter_isdefault : 1;
  p_expression _value;
  int _value_isdefault : 1;
};
#include <admsObject/objectVariable.h>
#include <admsObject/objectExpression.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_instanceparameter_uid (p_instanceparameter myinstanceparameter);
win32_interface int adms_instanceparameter_cmp (p_instanceparameter myinstanceparameter,p_instanceparameter refinstanceparameter);
win32_interface p_instanceparameter adms_instanceparameter_new(p_variable myparameter);
win32_interface p_adms adms_instanceparameter_new_impl (p_adms arguments[]);
#define adms_instanceparameter(member) ((p_instanceparameter) (member))
#define adms_instanceparameter_isdefault_parameter(instanceparameter) (adms_instanceparameter(instanceparameter)->_parameter_isdefault)
#define adms_instanceparameter_valueof_parameter(instanceparameter) (adms_instanceparameter(instanceparameter)->_parameter)
#define adms_instanceparameter_isdefault_value(instanceparameter) (adms_instanceparameter(instanceparameter)->_value_isdefault)
#define adms_instanceparameter_valueof_value(instanceparameter) (adms_instanceparameter(instanceparameter)->_value)
#define adms_instanceparameter_valueof_math(instanceparameter) ((p_math)instanceparameter)
#define adms_instanceparameter_valueof_adms(instanceparameter) ((p_adms)instanceparameter)
win32_interface inline void adms_instanceparameter_valueto_parameter (p_instanceparameter myinstanceparameter,p_variable _parameter);
win32_interface inline void adms_instanceparameter_valueto_value (p_instanceparameter myinstanceparameter,p_expression _value);
win32_interface inline void adms_instanceparameter_free(p_instanceparameter myinstanceparameter);
#endif /* objectinstanceparameter_h */
